import { CssBlockError, ErrorWithPosition } from "@css-blocks/core";
import chalk = require("chalk");
import yargs = require("yargs");
import { ExtractionResult } from "./extract-lines-from-source";
interface ValidateOptions {
    /**
     * A path to the preprocessors code.
     */
    preprocessors?: string;
    alias?: Array<string | number>;
    npm?: boolean;
}
export declare class CLI {
    constructor();
    /**
     * Parse the arguments and run the corresponding code.
     */
    run(args: Array<string>): Promise<void>;
    /**
     * this is an instance method so tests can disable it.
     */
    get chalk(): chalk.Chalk & {
        supportsColor: chalk.ColorSupport;
    };
    /**
     * Construct the argument parser using yargs.
     */
    argumentParser(): yargs.Argv<{
        preprocessors: string | undefined;
    } & {
        npm: boolean | undefined;
    } & {
        alias: (string | number)[] | undefined;
    }>;
    /**
     * Validate the syntax of a list of block files.
     */
    validate(blockFiles: Array<string>, options: ValidateOptions): Promise<void>;
    fileForError(e: CssBlockError): string | undefined;
    handleCssBlockError(blockFileRelative: string, error: CssBlockError): number;
    displayError(blockFileRelative: string, e: CssBlockError): void;
    displaySnippet(context: ExtractionResult | undefined, loc: ErrorWithPosition): void;
    splitLineOnErrorRange(line: string, lineNumber: number, loc: ErrorWithPosition): {
        before: string;
        during: string;
        after: string;
    };
    /**
     * Instance method so tests can easily capture output.
     */
    println(...args: Array<string>): void;
    /**
     * Instance method so tests can intercept the file write.
     */
    writeFile(filename: string, contents: string): Promise<void>;
    /**
     * Instance method so tests can record the exit code without exiting.
     */
    exit(code?: number): void;
}
export {};
//# sourceMappingURL=index.d.ts.map